@@ -1,13 +1,24 @@
 from django.shortcuts import render
 
+
+class TestClass(object):
+    def __init__(self):
+        self.arr = ['a', 1, 2]
+        self.dict = {'a': 1, 'b': 2}
+        self.num = 1
+
+    def test_method(self):
+        return True
+
+
 def injector_test(request):
-	return render(request, 'injector_test.html', {
-		'test_arr': [1, 2, 3, 4],
-		'test_dict': {
-			'a': 1,
-			'b': 2,
-			'c': 3
-		},
+    return render(request, 'injector_test.html', {
+        'test_arr': [1, 2, 3, 4],
+        'test_dict': {
+            'a': 1,
+            'b': 2,
+            'c': 3
+        },
         'test_str': 'hey',
         'test_int': 2,
         'test_bool': True,
@@ -19,5 +30,6 @@ def injector_test(request):
             'b': unicode('test'),
             1: 'c',
             'c': '\'test\''
-        }
-	})
\ No newline at end of file
+        },
+        'test_class': TestClass()
+    })
\ No newline at end of file
